@@ -17,6 +17,7 @@ class WH:
         self.temp_wh0 = cp.Variable(1)
         self.heat_on = cp.Variable(self.hems.horizon, integer=True)
         self.p_elec = cp.Variable(self.hems.horizon)
+        self.temp_delta = cp.Variable(self.hems.horizon)
 
         # Water heater temperature constants
         self.r = cp.Constant(float(self.hems.home["wh"]["r"]) * 1000)
@@ -53,7 +54,6 @@ class WH:
         df = np.divide(self.draw_size, self.wh_size)
         self.draw_frac = cp.Constant(df)
         self.remainder_frac = cp.Constant(1-df)
-
         return
 
     def add_constraints(self, enforce_bounds=True):
@@ -69,8 +69,9 @@ class WH:
             # thermal constraints, expected value after approx waterdraws
             self.temp_wh_ev[0] == self.hems.temp_wh_init,
             self.temp_wh_ev[1:] == (cp.multiply(self.remainder_frac[1:],self.temp_wh_ev[:-1]) 
-                                + self.draw_frac[1:]*self.tap_temp)
-                                + (3600 * self.hems.dt_frac) * ((((self.hems.hvac.temp_in_ev[1:] 
+                                + self.draw_frac[1:]*self.tap_temp) + self.temp_delta,
+
+            self.temp_delta == (3600 * self.hems.dt_frac) * ((((self.hems.hvac.temp_in_ev[1:] 
                                     - (cp.multiply(self.remainder_frac[1:],self.temp_wh_ev[:-1]) 
                                     + self.draw_frac[1:]*self.tap_temp)) / self.r))
                                     + self.heat_on * self.p) / (self.c),
@@ -81,7 +82,8 @@ class WH:
                             + self.heat_on[0] * self.p) / (self.c),
 
             # actual value of temperature of tank at time t=0, after any water draw occurs, before heating
-            self.temp_wh == ((self.temp_wh0 * (self.wh_size - self.draw_size[0])) + (self.tap_temp * self.draw_size[0])) / self.wh_size,
+            # self.temp_wh == ((self.temp_wh0 * self.remainder_frac[0]) + (self.tap_temp * self.draw_frac[0])), #/ self.wh_size,
+            self.temp_wh == self.temp_wh_ev[1],
 
             # electrical power as a function of thermal power
             self.heat_on <= self.wh_heat_max,
@@ -112,16 +114,58 @@ class WH:
         """
         cons = self.add_constraints()
         obj = cp.Minimize(cp.abs(self.temp_wh - self.temp_wh_min))
+        # obj = cp.Maximize(self.temp_wh)
         prob = cp.Problem(obj, cons)
         prob.solve(solver=self.hems.solver)
-
         if not prob.status == 'optimal':
             cons = self.add_constraints(enforce_bounds=False)
-            obj = cp.Minimize(cp.abs(self.temp_wh - self.temp_wh_min))
+            obj = cp.Minimize(self.temp_wh_min - self.temp_wh)
             prob = cp.Problem(obj, cons)
             prob.solve(solver=self.hems.solver, verbose=False)
             print(prob.status)
 
+    def add_override_cons(self):
+        """
+        :parameter enforce_bounds: boolean determines whether comfort bounds are strictly enforced
+        :return: cons, a list of CVXPY constraints
+
+        A method to introduce physical constraints to the water heater. 
+        """
+        self._get_water_draws()
+
+        cons = [
+            # thermal constraints, expected value after approx waterdraws
+            self.temp_wh_ev[0] == self.hems.temp_wh_init,
+            self.temp_wh_ev[1:] == (cp.multiply(self.remainder_frac[1:],self.temp_wh_ev[:-1]) 
+                                + self.draw_frac[1:]*self.tap_temp) + self.temp_delta,
+
+            self.temp_delta == (3600 * self.hems.dt_frac) * ((((self.copy_hvac 
+                                    - (cp.multiply(self.remainder_frac[1:],self.temp_wh_ev[:-1]) 
+                                    + self.draw_frac[1:]*self.tap_temp)) / self.r))
+                                    + self.heat_on * self.p) / (self.c),
+
+            # actual value of temperature of tank at time t="-0.5", before any water draw occurs
+            self.temp_wh0 == self.hems.temp_wh_init
+                            + (3600 * self.hems.dt_frac) * (((self.copy_hvac[0] - self.hems.temp_wh_init) / self.r)
+                            + self.heat_on[0] * self.p) / (self.c),
+
+            # actual value of temperature of tank at time t=0, after any water draw occurs, before heating
+            # self.temp_wh == ((self.temp_wh0 * self.remainder_frac[0]) + (self.tap_temp * self.draw_frac[0])), #/ self.wh_size,
+            self.temp_wh == self.temp_wh_ev[1],
+
+            # electrical power as a function of thermal power
+            self.heat_on <= self.wh_heat_max,
+            self.heat_on >= self.wh_heat_min,
+            self.p_elec == (self.heat_on * self.p) / self.hems.sub_subhourly_steps, # kW
+
+            self.temp_wh >= self.temp_wh_min,
+            self.temp_wh <= self.temp_wh_max,
+            self.temp_wh_ev >= self.temp_wh_min,
+            self.temp_wh_ev <= self.temp_wh_max,
+            ]
+
+        return cons 
+
     def override_p_wh(self, cmd):
         """
         :parameter cmd: float in [-1,1]
@@ -132,5 +176,22 @@ class WH:
         exceed bounds in either direction.
         """
         self.obj = cp.Variable(1)
-        cons = [self.obj == (2 * cmd + 1) - (self.heat_on / self.wh_heat_max)]
-        return cons 
\ No newline at end of file
+        self.copy_hvac = self.hems.hvac.temp_in_ev[1:].value
+        cons = self.add_override_cons()
+
+        cmd = (0.5 * cmd + 0.5)
+        obj_cons = [self.obj == (cmd - (self.heat_on[0] / self.wh_heat_max)), self.obj >= 0]
+        obj = cp.Minimize(self.obj)
+        prob = cp.Problem(obj, cons + obj_cons)
+        prob.solve(solver=self.hems.solver)
+        
+        if not prob.status == 'optimal':
+            obj_cons = [self.obj == (self.heat_on[0] / self.wh_heat_max) - (0.5 * cmd + 0.5)]
+            prob = cp.Problem(obj, cons + obj_cons)
+            prob.solve(solver=self.hems.solver)
+
+            if not prob.status == 'optimal':
+                print('resolve')
+                self.resolve()
+
+        return obj_cons 
\ No newline at end of file
